@@ -22,7 +22,9 @@ def execute_with_run_as_root_equals_true(context, config):
 
     if (context.call_function_name_qual in config['function_names']):
         if context.check_call_arg_value('run_as_root', 'True'):
-
-            return(bandit.INFO, 'execute with run_as_root=True '
-                   'identified, possible security issue.  %s' %
-                   context.call_args_string)
+            return bandit.Issue(
+                severity=bandit.LOW,
+                confidence=bandit.MEDIUM,
+                text="Execute with run_as_root=True identified, possible "
+                     "security issue."
+            )
