@@ -24,6 +24,7 @@ import testtools
 from bandit.core import config as b_config
 from bandit.core import constants as C
 from bandit.core import manager as b_manager
+from bandit.core import metrics
 from bandit.core import test_set as b_test_set
 
 
@@ -89,15 +90,15 @@ class FunctionalTests(testtools.TestCase):
         :param example_script: Filename of an example script to test
         :param expect: dict with expected values of metrics
         '''
-        # reset scores and metrics for subsequent calls to run_example
+        self.b_mgr.metrics = metrics.Metrics()
         self.b_mgr.scores = []
-        self.b_mgr.metrics = {}
         self.run_example(example_script)
-        metrics = self.b_mgr.metrics
+
         # test general metrics (excludes issue counts)
+        m = self.b_mgr.metrics.data
         for k in expect:
             if k != 'issues':
-                self.assertEqual(expect[k], metrics['_totals'][k])
+                self.assertEqual(expect[k], m['_totals'][k])
         # test issue counts
         if 'issues' in expect:
             for (criteria, default) in C.CRITERIA:
@@ -106,7 +107,7 @@ class FunctionalTests(testtools.TestCase):
                     expected = 0
                     if expect['issues'].get(criteria, None).get(rank, None):
                         expected = expect['issues'][criteria][rank]
-                    self.assertEqual(expected, metrics['_totals'][label])
+                    self.assertEqual(expected, m['_totals'][label])
 
     def test_binding(self):
         '''Test the bind-to-0.0.0.0 example.'''
@@ -167,7 +168,7 @@ class FunctionalTests(testtools.TestCase):
     def test_imports_aliases(self):
         '''Test the `import X as Y` syntax.'''
         expect = {
-            'SEVERITY': {'LOW': 3, 'MEDIUM': 5, 'HIGH': 1},
+            'SEVERITY': {'LOW': 4, 'MEDIUM': 5, 'HIGH': 0},
             'CONFIDENCE': {'HIGH': 9}
         }
         self.check_example('imports-aliases.py', expect)
@@ -296,8 +297,8 @@ class FunctionalTests(testtools.TestCase):
     def test_subprocess_shell(self):
         '''Test for `subprocess.Popen` with `shell=True`.'''
         expect = {
-            'SEVERITY': {'HIGH': 5, 'MEDIUM': 1, 'LOW': 7},
-            'CONFIDENCE': {'HIGH': 13}
+            'SEVERITY': {'HIGH': 2, 'MEDIUM': 2, 'LOW': 12},
+            'CONFIDENCE': {'HIGH': 16}
         }
         self.check_example('subprocess_shell.py', expect)
 
@@ -309,7 +310,7 @@ class FunctionalTests(testtools.TestCase):
     def test_utils_shell(self):
         '''Test for `utils.execute*` with `shell=True`.'''
         expect = {
-            'SEVERITY': {'HIGH': 4, 'LOW': 1},
+            'SEVERITY': {'LOW': 5},
             'CONFIDENCE': {'HIGH': 5}
         }
         self.check_example('utils-shell.py', expect)
@@ -317,7 +318,7 @@ class FunctionalTests(testtools.TestCase):
     def test_wildcard_injection(self):
         '''Test for wildcard injection in shell commands.'''
         expect = {
-            'SEVERITY': {'HIGH': 5, 'MEDIUM':3, 'LOW': 6},
+            'SEVERITY': {'HIGH': 4, 'MEDIUM':4, 'LOW': 6},
             'CONFIDENCE': {'MEDIUM': 8, 'HIGH': 6}
         }
         self.check_example('wildcard-injection.py', expect)
@@ -434,8 +435,8 @@ class FunctionalTests(testtools.TestCase):
     def test_weak_cryptographic_key(self):
         '''Test for weak key sizes.'''
         expect = {
-            'SEVERITY': {'MEDIUM': 4, 'HIGH': 4},
-            'CONFIDENCE': {'HIGH': 8}
+            'SEVERITY': {'MEDIUM': 5, 'HIGH': 4},
+            'CONFIDENCE': {'HIGH': 9}
         }
         self.check_example('weak_cryptographic_key_sizes.py', expect)
 
@@ -459,3 +460,34 @@ class FunctionalTests(testtools.TestCase):
         self.assertEqual(5, issues[1].lineno)
         self.assertEqual(list(range(3, 6+1)), issues[1].linerange)
         self.assertIn('shell=True', issues[1].get_code())
+
+    def test_flask_debug_true(self):
+        expect = {
+            'SEVERITY': {'HIGH': 1},
+            'CONFIDENCE': {'MEDIUM': 1}
+        }
+        self.check_example('flask_debug.py', expect)
+
+    def test_baseline_filter(self):
+        json = """{
+          "results": [
+            {
+              "code": "...",
+              "filename": "%s/examples/flask_debug.py",
+              "issue_confidence": "MEDIUM",
+              "issue_severity": "HIGH",
+              "issue_text": "A Flask app appears to be run with debug=True ..",
+              "line_number": 10,
+              "line_range": [
+                10
+              ],
+              "test_name": "flask_debug_true"
+            }
+          ]
+        }
+        """ % os.getcwd()
+
+        self.b_mgr.populate_baseline(json)
+        self.run_example('flask_debug.py')
+        self.assertEqual(len(self.b_mgr.baseline), 1)
+        self.assertEqual(self.b_mgr.get_issue_list(), [])
